@@ -13,7 +13,7 @@ use panic_semihosting as _;
 
 use bsp::entry;
 use hal::clock::GenericClockController;
-use hal::gpio::v2::M;
+use hal::gpio::M;
 
 use pac::gclk::genctrl::SRC_A::DPLL0;
 use pac::gclk::pchctrl::GEN_A::GCLK2;
@@ -36,5 +36,7 @@ fn main() -> ! {
         .configure_gclk_divider_and_source(GCLK2, 12, DPLL0, false)
         .unwrap();
     let _ = pins.d7.into_alternate::<M>();
-    loop {}
+    loop {
+        cortex_m::asm::wfi();
+    }
 }
